@@ -92,6 +92,26 @@ LO_SW_SPECIES_VARIABLE_NAMES = [
     "heplus",
     "cnoplus",
 ]
+LO_SW_SOLAR_WIND_SPECIES_VARIABLE_NAMES = [
+    "hplus",
+    "heplusplus",
+    "cplus4",
+    "cplus5",
+    "cplus6",
+    "oplus5",
+    "oplus6",
+    "oplus7",
+    "oplus8",
+    "ne",
+    "mg",
+    "si",
+    "fe_loq",
+    "fe_hiq",
+]
+LO_SW_PICKUP_ION_SPECIES_VARIABLE_NAMES = [
+    "heplus",
+    "cnoplus",
+]
 LO_NSW_SPECIES_VARIABLE_NAMES = [
     "hplus",
     "heplusplus",
@@ -2259,3 +2279,44 @@ HALF_SPIN_LUT = {
     30: [116, 117, 118, 119, 120, 121],
     31: [122, 123, 124, 125, 126, 127],
 }
+
+NSW_POSITIONS = [x for x in range(3, 22)]
+SW_POSITIONS = [0]
+PUI_POSITIONS = [0, 1, 2, 22, 23]
+L2_GEOMETRIC_FACTOR = 0.013
+L2_HI_NUMBER_OF_SSD = 12.0
+
+L2_HI_SECTORED_ANGLE = np.array(
+    [
+        285.00,
+        244.11,
+        228.69,
+        225.00,
+        228.69,
+        244.11,
+        285.00,
+        325.89,
+        341.31,
+        345.00,
+        341.31,
+        325.89,
+    ]
+)
+
+HI_L2_ELEVATION_ANGLE = np.array(
+    [
+        150.0,
+        138.6,
+        115.7,
+        90.0,
+        64.3,
+        41.4,
+        30.0,
+        41.4,
+        64.3,
+        90.0,
+        115.7,
+        138.6,
+    ],
+    dtype=float,
+)
